@@ -4,8 +4,7 @@ import sentry_sdk
 from sentry_sdk.integrations.logging import LoggingIntegration
 
 
-def init_sentry(enabled: bool = False, exclude_errors: bool = False):
-    return
+def init_sentry(enabled: bool = False, exclude_errors: bool = False) -> None:  # noqa: FBT001, FBT002
     if enabled:
         sentry_logging = LoggingIntegration(
             level=logging.INFO,  # Capture info and above as breadcrumbs
@@ -13,6 +12,7 @@ def init_sentry(enabled: bool = False, exclude_errors: bool = False):
             if exclude_errors
             else logging.ERROR,  # Otherwise, error logs will create sentry events
         )
+
         sentry_sdk.init(
             dsn="https://4b9a1902f9361b48c04376df6483bc96@o4506833230561280.ingest.sentry.io/4506833262477312",
             integrations=[sentry_logging],
@@ -23,4 +23,5 @@ def init_sentry(enabled: bool = False, exclude_errors: bool = False):
             # of sampled transactions.
             # We recommend adjusting this value in production.
             profiles_sample_rate=1.0,
+            ignore_errors=[KeyboardInterrupt],
         )
